/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.beans.factory.deployment;

import org.springframework.context.ApplicationContext;
import org.springframework.context.support.GenericApplicationContext;
import org.springframework.core.io.ResourceLoader;

/**
 * Interface to be implemented by classes that can bootstrap a Spring container,
 * for example to start a Spring deployment unit within a server environment.
 * @author Rod Johnson
 */
public interface ContainerBootstrap {
	
	/**
	 * Start a Spring container preloading from the given locations
	 * @param parent parent context, may be null
	 * @param requiredLocations Spring locations that must be loadable (using the
	 * given ResourceLoader) for the deployment to succeed
	 * @param optionalLocations Spring locations that will be processed if present.
	 * Not an error if one or more are unavailable.
	 * @param resourceLoader Spring ResourceLoader to use to load locations.
	 * May be null
	 * @return a new Spring container with the given parent and having
	 * loaded singleton definitions from the locations
	 */
	GenericApplicationContext bootstrap(
			ApplicationContext parent,
			String[] requiredLocations, 
			String[] optionalLocations, 
			ResourceLoader resourceLoader);

}
