/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.beans.factory.deployment;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.beans.factory.BeanDefinitionStoreException;
import org.springframework.beans.factory.xml.XmlBeanDefinitionReader;
import org.springframework.context.ApplicationContext;
import org.springframework.context.support.GenericApplicationContext;
import org.springframework.core.io.ResourceLoader;

/**
 * Default implementation of the ContainerBootstrap interface.
 * 
 * @author Rod Johnson
 */
public class DefaultContainerBootstrap implements ContainerBootstrap {
	
	protected final Log log = LogFactory.getLog(getClass());
	
	public GenericApplicationContext bootstrap(
			ApplicationContext parent,
			String[] requiredLocations,
			String[] optionalLocations, 
			ResourceLoader resourceLoader) {
		
		// The application context for each deployment is a child of the server application context 
		GenericApplicationContext deploymentContext = new GenericApplicationContext(parent);
		if (resourceLoader != null) {
			deploymentContext.setResourceLoader(resourceLoader);
		}

		// Now load common definitions for all JAR deployments in this server
		XmlBeanDefinitionReader childBdr = new XmlBeanDefinitionReader(deploymentContext);
		for (String requiredLocation : requiredLocations) {
			childBdr.loadBeanDefinitions(requiredLocation);
		}
		
		// Register Spring XML file customizing singleton deployment.
		// This is optional
		for (String optionalLocation : optionalLocations) {
			try {
				childBdr.loadBeanDefinitions(optionalLocation);
			}
			catch (BeanDefinitionStoreException ex) {
				log.info("Did not find optional Spring deployment descriptor: " + ex.getMessage());
			}
		}
		
		return deploymentContext;
	}

}
