/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.jee.config;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.beans.BeansException;
import org.springframework.beans.factory.BeanFactory;
import org.springframework.beans.factory.BeanFactoryAware;
import org.springframework.beans.factory.config.InstantiationAwareBeanPostProcessorAdapter;
import org.springframework.beans.factory.support.BeanDefinitionRegistry;
import org.springframework.core.Ordered;

/**
 * Superclass for post processing singleton definitions, driven by a matching
 * piece of metadata attached to the relevant singleton definition with the
 * given name.
 * 
 * @author Rod Johnson
 */
public class MetadataDrivenBeanPostProcessorSupport extends InstantiationAwareBeanPostProcessorAdapter 
								implements Ordered, BeanFactoryAware {

	protected final Log log = LogFactory.getLog(getClass());

	protected BeanFactory owner;

	private final String attributeName;

	protected BeanDefinitionRegistry beanDefinitionRegistry;

	private int order = Integer.MIN_VALUE;

	public MetadataDrivenBeanPostProcessorSupport(String attributeName) {
		this.attributeName = attributeName;
	}

	public void setBeanFactory(BeanFactory bf) throws BeansException {
		this.owner = bf;

		if (!(bf instanceof BeanDefinitionRegistry))
			throw new IllegalArgumentException("beanFactory needs to implement "
					+ BeanDefinitionRegistry.class.getName() + " interface");
		this.beanDefinitionRegistry = (BeanDefinitionRegistry) owner;
	}

	public void setOrder(int order) {
		this.order = order;
	}

	public int getOrder() {
		return order;
	}

	protected Object getMetadata(String beanName) {
		// Avoid problems with inner beans
		if (!beanDefinitionRegistry.containsBeanDefinition(beanName)) {
			return null;
		}

		return beanDefinitionRegistry.getBeanDefinition(beanName).getAttribute(attributeName);
	}

	
}
