/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.jee.ejb;

import java.lang.reflect.Field;

import javax.ejb.EJB;

import org.springframework.jee.inject.FieldInjection;
import org.springframework.jee.inject.InjectionInfo;

/**
 * Field level @EJB injection.
 * 
 * @author Costin Leau
 * 
 */
public class EjbFieldInjection extends FieldInjection {

	private String defaultName;

	public EjbFieldInjection(Field f, EJB annotation) {
		this(f, new EjbReferenceInfo(annotation));
	}

	public EjbFieldInjection(Field f, InjectionInfo er) {
		// TODO validate must not be final
		super(f, er);
		defaultName = composeDefaultName(f);
	}

	private String composeDefaultName(Field f) {
		return f.getDeclaringClass().getName() + "/" + f.getName();
	}

	@Override
	protected String getDefaultName() {
		return defaultName;
	}
}
