/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.jee.ejb;

import java.util.ArrayList;
import java.util.List;

import org.springframework.jee.inject.DeploymentUnitMetadata;
import org.springframework.jee.inject.Injection;
import org.springframework.jee.transaction.TransactionalMetadata;

/**
 * Metadata for @EJB injection. Extends TransactionalMetadata and adds support for
 * EJB injections.
 * 
 * @author Costin Leau
 * 
 */
public class EjbInjectionMetadata extends TransactionalMetadata {

	private List<Injection<EjbReferenceInfo>> ejbInjections = new ArrayList<Injection<EjbReferenceInfo>>();

	public EjbInjectionMetadata(DeploymentUnitMetadata deploymentUnitMetadata, String name, Class<?> componentClass) {
		super(deploymentUnitMetadata, name, componentClass);
	}

	public List<Injection<EjbReferenceInfo>> getEjbInjections() {
		return ejbInjections;
	}

	public void addEjbInjection(Injection<EjbReferenceInfo> fi) {
		this.ejbInjections.add(fi);
	}

	@Override
	public void inject(Object instance) {
		super.inject(instance);
		applyInjections(instance, ejbInjections);
	}

}
