/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.jee.ejb;

import org.springframework.aop.framework.ProxyFactory;
import org.springframework.jee.inject.DeploymentUnitMetadata;
import org.springframework.jee.intercept.InterceptionMetadata;


/**
 * Metadata for an EJB. Extends InterceptionMetadata to
 * add additional EJB metadata such as singleton type, and do
 * more sophisticated proxying to handle EJB component model contract.
 * Does <b>not</b> do Spring transaction management: this is assumed to be provided by the container.
 * @author Rod Johnson
 *
 */
public class EjbMetadata extends InterceptionMetadata {
	
	private final BeanType beanType;

	/**
	 * @param name
	 * @param componentClass
	 */
	public EjbMetadata(DeploymentUnitMetadata dum, String name, Class<?> componentClass, BeanType beanType) {
		super(dum, name, componentClass);
		this.beanType = beanType;
	}
	
	/**
	 * @return the beanType
	 */
	public BeanType getBeanType() {
		return this.beanType;
	}

	
	@Override
	protected void addComponentContractInterceptors(ProxyFactory pf) {
		// TODO add EJB contract stuff
		throw new UnsupportedOperationException("Should add EJB decoration");
	}


}
