/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.jee.ejb;

import java.lang.reflect.Method;

import javax.ejb.EJB;

import org.springframework.jee.inject.InjectionInfo;
import org.springframework.jee.inject.MethodInjection;

/**
 * Method level @EJB injection.
 *  
 * @author Costin Leau
 * 
 */
public class EjbMethodInjection extends MethodInjection {

	private String defaultName;

	public EjbMethodInjection(Method m, InjectionInfo ei) {
		super(m, ei);
		defaultName = composeDefaultName(m);
	}

	public EjbMethodInjection(Method m, EJB annotation) {
		this(m, new EjbReferenceInfo(annotation));
	}

	protected String composeDefaultName(Method m) {
		return m.getDeclaringClass().getName() + "/" + fieldName;
	}

	@Override
	protected String getDefaultName() {
		return defaultName;
	}
	
	
}
