/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.jee.ejb;

import javax.ejb.EJB;

import org.springframework.jee.inject.BasicInjectionInfo;
import org.springframework.util.StringUtils;

/**
 * Information holder for @EJB injection.
 * 
 * @author Costin Leau
 * 
 */
public class EjbReferenceInfo extends BasicInjectionInfo {

	private static final String INJECTION_NAME = "@EJB";

	public EjbReferenceInfo(EJB annotation) {
		if (StringUtils.hasText(annotation.name()))
			name = annotation.name();

		Class intface = annotation.beanInterface();
		if (intface != null && intface != Object.class)
			type = intface;
	}

	public EjbReferenceInfo(String name, Class type) {
		super(name, type);
	}

	@Override
	public String getInjectionName() {
		return INJECTION_NAME;
	}
}
