/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.jee.ejb.config;

import java.util.ArrayList;
import java.util.List;

import org.springframework.jee.config.JeeBeanFactoryPostProcessor;
import org.springframework.jee.ejb.EjbInjectionMetadata;
import org.springframework.jee.ejb.EjbReferenceProcessor;
import org.springframework.jee.inject.BeanDefinitionAnnotationComponentContributor;
import org.springframework.jee.inject.ChainedProcessorsComponentContributor;
import org.springframework.jee.inject.DeploymentUnitMetadata;
import org.springframework.jee.inject.Jsr250Metadata;
import org.springframework.jee.inject.MetadataProcessor;

/**
 * PostProcessor that adds @EJB style injections.
 * 
 * @author Costin Leau
 * 
 */
public class JeeEjbBeanFactoryPostProcessor extends JeeBeanFactoryPostProcessor {

	@Override
	protected BeanDefinitionAnnotationComponentContributor createComponentContributor(
			DeploymentUnitMetadata deploymentUnitMetadata) {
		BeanDefinitionAnnotationComponentContributor bdcc = new BeanDefinitionAnnotationComponentContributor(
				deploymentUnitMetadata) {

			@Override
			public Jsr250Metadata newJsr250Metadata(String componentName, Class<?> componentClass,
					DeploymentUnitMetadata dum) {
				return new EjbInjectionMetadata(dum, componentName, componentClass);
			}
		};

		List<MetadataProcessor> processors = new ArrayList<MetadataProcessor>();
		processors.addAll(ChainedProcessorsComponentContributor.DEFAULT_PROCESSORS);
		processors.add(new EjbReferenceProcessor());
		bdcc.setMetadataProcessors(processors);
		return bdcc;
	}
}
