/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.jee.inject;

import javax.ejb.Stateful;
import javax.ejb.Stateless;

/**
 * ComponentContributor targeted at an array of classes, useful in tests. 
 * 
 * @author Rod Johnson
 */
public class AnnotationComponentContributor extends ChainedProcessorsComponentContributor {

	private final Class[] classes;

	public AnnotationComponentContributor(Class... classes) {
		this.classes = classes;
	}

	public void contribute(Enricher enricher) {
		for (Class componentClass : classes) {
			log.info("Examining metadata for " + componentClass);
			String componentName = findComponentName(componentClass);
			enricher.attach(findComponentMetadata(componentName, componentClass, enricher.getDeploymentUnitMetadata()));
		}
	}

	/**
	 * Find specified name or default.
	 * 
	 * @param ejbClass
	 * @return
	 */
	private String findComponentName(Class ejbClass) {
		Stateless stateless = (Stateless) ejbClass.getAnnotation(Stateless.class);
		if (stateless != null && stateless.name().length() > 0) {
			return stateless.name();
		}

		Stateful stateful = (Stateful) ejbClass.getAnnotation(Stateful.class);
		if (stateful != null && stateful.name().length() > 0) {
			return stateful.name();
		}
		// Default is unqualified name
		return ejbClass.getSimpleName();
	}

}
