/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.jee.inject;

/**
 * Interface to be implemented by objects that can contribute JEE metadata to an existing Spring context.
 * @author Rod Johnson
 *
 */
public interface ComponentContributor {
	
	/**
	 * Contribute metadata.
	 * 
	 * @param enricher object to use to attach or enrich metadata 
	 */
	void contribute(Enricher enricher);

	/**
	 * Create a instance or subclass instance of Jsr250Metadata.
	 * 
	 * @param componentName component name
	 * @param componentClass class of the component
	 * @param dum deployment unit metadata
	 * @return new instance of Jsr250Metadata or a subclass
	 */
	Jsr250Metadata newJsr250Metadata(String componentName,
			Class<?> componentClass, DeploymentUnitMetadata dum);
}