/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.jee.inject;

import java.lang.reflect.Field;
import java.lang.reflect.Modifier;

import javax.annotation.Resource;

import org.springframework.util.ReflectionUtils;

/**
 * JSR 250 field level injection.
 * 
 * @author Rod Johnson
 * @author Costin Leau
 * 
 */
public class FieldInjection extends Injection {

	public FieldInjection(Field f, InjectionInfo ri) {
		super(f, ri);
	}

	public FieldInjection(Field f, Resource annotation) {
		this(f, new ResourceInfo(annotation));
	}

	@Override
	public void apply(Object instance, Object value) {
		try {
			Field f = (Field) member;
			boolean oldAccessible = f.isAccessible();
			boolean shouldSetAccessible = (!Modifier.isPublic(f.getModifiers()) && !oldAccessible);
			if (shouldSetAccessible) {
				f.setAccessible(true);
			}
			f.set(instance, value);

			if (shouldSetAccessible) {
				f.setAccessible(oldAccessible);
			}

		}
		catch (IllegalArgumentException ex) {
			// TODO deployment exception
			throw new UnsupportedOperationException("Cannot inject value of class '" + value.getClass() + "' into "
					+ member);
		}
		catch (IllegalAccessException ex) {
			ReflectionUtils.handleReflectionException(ex);
		}
	}

	@Override
	protected Class getMemberType() {
		return ((Field) member).getType();
	}
}
