/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.jee.inject;

import org.springframework.beans.BeansException;
import org.springframework.jee.config.MetadataDrivenBeanPostProcessorSupport;

/**
 * BeanPostProcessor that performs JEE Dependency Injection.
 * This ensures it takes place before Spring DI.
 * JEE injection is driven by JeeMetadata that will have been attached to 
 * each eligible Spring singleton definition by previous processing.
 * 
 * @author Rod Johnson
 */
public class Jsr250MetadataBeanPostProcessor extends MetadataDrivenBeanPostProcessorSupport {
	
	public Jsr250MetadataBeanPostProcessor() {
		super(Jsr250Metadata.KEY);
	}
	
	@Override
	public boolean postProcessAfterInstantiation(Object bean, String beanName) throws BeansException {
		Jsr250Metadata jsr250 = (Jsr250Metadata) getMetadata(beanName);
		if (jsr250 != null) {
			jsr250.injectAndPostConstruct(bean);
		}
		return true;
	}

}
