/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.jee.inject;

import java.lang.annotation.Annotation;

import javax.annotation.PostConstruct;
import javax.annotation.PreDestroy;
import javax.ejb.PostActivate;
import javax.ejb.PrePassivate;

/**
 * Enumeration for lifecycle events on a JEE component, along with the
 * corresponding annotations that may be used to identify them in 
 * Java source.
 * @author Rod Johnson
 */
public enum LifecycleEvent {
	
	POST_CONSTRUCT(PostConstruct.class),
	PRE_DESTROY(PreDestroy.class),
	// TODO: move this into Ejb3 or interception metadata
	POST_ACTIVATE(PostActivate.class),
	PRE_PASSIVATE(PrePassivate.class);
	
	private Class<? extends Annotation> A;
	
	private LifecycleEvent(Class<? extends Annotation> A) {
		this.A = A;
	}

	public Class<? extends Annotation> getAnnotation() {
		return A;
	}
}