/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.jee.inject;

import java.lang.reflect.Method;

import javax.annotation.Resource;

import org.springframework.util.ReflectionUtils;

/**
 * JSR 250 method level injection.
 * 
 * @author Rod Johnson
 * @author Costin Leau
 * 
 */
public class MethodInjection extends Injection {

	protected String fieldName;

	public MethodInjection(Method m, InjectionInfo ri) {
		super(m, ri);
		// when dealing with methods extract the enclosed field name.
		fieldName = extractName(m);
	}

	public MethodInjection(Method m, Resource annotation) {
		this(m, new ResourceInfo(annotation));
	}

	@Override
	public void apply(Object instance, Object value) {
		ReflectionUtils.invokeMethod((Method) member, instance, new Object[] { value });
	}

	@Override
	protected Class getMemberType() {
		return ((Method) member).getParameterTypes()[0];
	}

	
	// TODO: should this be implemented (MethodInjection return the fieldName
	//public String getName() {
	//	return name;
	//}

	private String extractName(Method m) {
		// extract the field from method signature
		return Character.toLowerCase(m.getName().charAt(3)) + m.getName().substring(4);
	}
}
