/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.jee.inject;

import javax.annotation.Resource;

import org.springframework.util.StringUtils;

/**
 * JSR 250 resource information holder.
 * 
 * @author Rod Johnson
 * @author Costin Leau
 * 
 */
public class ResourceInfo extends BasicInjectionInfo {

	private static final String INJECTION_NAME = "@Resource";

	public ResourceInfo(Resource annotation) {
		if (StringUtils.hasText(annotation.name()))
			this.name = annotation.name();
		Class type = annotation.type();
		if (type != null && type != Object.class)
			this.type = type;
	}

	public ResourceInfo(String name, Class type) {
		super(name, type);
	}

	@Override
	public String getInjectionName() {
		return INJECTION_NAME;
	}

}