/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.jee.intercept;

import org.springframework.beans.BeansException;
import org.springframework.jee.inject.Jsr250MetadataBeanPostProcessor;
import org.springframework.jee.inject.LifecycleEvent;

/**
 * Spring BeanPostProcessor that performs JEE interception on components with
 * InterceptionMetadata.
 * 
 * @author Rod Johnson
 * 
 */
public class InterceptionMetadataBeanPostProcessor extends
		Jsr250MetadataBeanPostProcessor {

	
	@Override
	public Object postProcessAfterInitialization(Object bean, String beanName)
			throws BeansException {
		Object o = getMetadata(beanName);
		if (o == null || (!(o instanceof InterceptionMetadata))) {
			return bean;
		}
			
		InterceptionMetadata im = (InterceptionMetadata) getMetadata(beanName);
		
		Object maybeProxy = im.createProxyIfNecessary(bean);
		
		// If the singleton is a proxy, it will implement the (introduced)
		// __ProxyControl interface. Lifecycle methods will be called
		// through this interface.
		if (maybeProxy instanceof __ProxyControl) {
			((__ProxyControl) maybeProxy).invokeLifecycleMethod(LifecycleEvent.POST_CONSTRUCT);
		}
		return maybeProxy;
	}

}
