/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.jee.intercept;

import java.lang.reflect.Method;
import java.util.Map;

import javax.ejb.EJBContext;
import javax.ejb.EJBException;
import javax.interceptor.InvocationContext;

import org.springframework.aop.framework.ReflectiveMethodInvocation;

/**
 * Implementation of EJB3 InvocationContext for interception built on Spring
 * ReflectiveMethodInvocation and AOP Alliance API.
 * 
 * @author Rod Johnson
 * @author Michael Chen
 */
public class MethodInvocationInvocationContext implements InvocationContext {

	private final ReflectiveMethodInvocation mi;

	public MethodInvocationInvocationContext(ReflectiveMethodInvocation mi) {
		this.mi = mi;
	}

	public Object getTarget() {
		return mi.getThis();
	}

	public Method getMethod() {
		return mi.getMethod();
	}

	public Object[] getParameters() {
		return mi.getArguments();
	}

	public void setParameters(Object[] parms) {
		// TODO a little fragile
		for (int i = 0; i < parms.length; i++) {
			mi.getArguments()[i] = parms[i];
		}
	}

	public EJBContext getEJBContext() {
		// return getBeanInstanceMetadata().getEJBContext();
		throw new UnsupportedOperationException();
	}

	public Map<String, Object> getContextData() {
		return (Map<String, Object>) mi.getUserAttributes();
	}

	public Object proceed() throws Exception {
		try {
			return mi.proceed();
		}
		catch (Exception ex) {
			throw ex;
		}
		catch (Throwable t) {
			// TODO
			throw new EJBException("what do i do: seems an odd quirk of the EJB spec.  The exception is:" + t);
		}
	}

}