/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.jee.intercept;

import java.lang.reflect.Method;

import org.springframework.aop.support.StaticMethodMatcherPointcutAdvisor;

/**
 * Delegate pointcut advisor used for superInterceptors. It delegates the
 * matching to the base interceptor pointcut advisor.
 * 
 * @author Costin Leau
 * 
 */
public class SuperJeeInterceptorPointcutAdvisor extends StaticMethodMatcherPointcutAdvisor {

	private final JeeInterceptorPointcutAdvisor delegate;

	public SuperJeeInterceptorPointcutAdvisor(JeeInterceptorPointcutAdvisor delegate, JeeInterceptorInterceptor advice) {
		super(advice);
		this.delegate = delegate;
	}

	/* (non-Javadoc)
	 * @see org.springframework.aop.MethodMatcher#matches(java.lang.reflect.Method, java.lang.Class)
	 */
	public boolean matches(Method method, Class targetClass) {
		return delegate.matches(method, targetClass);
	}

	

}
