/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.jee.server;

import org.springframework.beans.factory.deployment.ContainerBootstrap;
import org.springframework.beans.factory.deployment.DefaultContainerBootstrap;
import org.springframework.context.support.GenericApplicationContext;
import org.springframework.core.io.ResourceLoader;
import org.springframework.jee.ejb.EjbAnnotationComponentContributor;
import org.springframework.jee.inject.ComponentContributor;
import org.springframework.jee.inject.DeploymentUnitMetadata;
import org.springframework.jee.validation.InvalidDeploymentUnitException;

/**
 * Customized bootstrap for EJB deployment. Includes the location of an optional
 * Spring EJB deployment descriptor container Spring definitions for any EJBs
 * that, for example, require Spring constructor injection.
 * 
 * @author Rod Johnson
 * @author Costin Leau
 */
public class EjbBootstrap extends Bootstrap {

	/**
	 * Spring deployment descriptor. Contains Spring singleton definitions,
	 * without class names, that correspond to EJB names. This allows Spring's
	 * more sophisticated dependency injection to be applied to EJB instances.
	 */
	public static final String SPRING_EJB_JAR_XML_LOCATION = "/META-INF/spring-ejb-jar.xml";

	public EjbBootstrap() {
		super();

	}
	
	public EjbBootstrap(ContainerBootstrap containerBootstrap) {
		super(containerBootstrap);
	}

	@Override
	public GenericApplicationContext deploy() throws InvalidDeploymentUnitException {
		return super.deploy(new EjbAnnotationComponentContributor());
	}

	/**
	 * 
	 * @param requiredSpringLocations
	 * @param resourceLoader
	 * @param componentContributor
	 * @param deploymentUnitMetadata may be null, in which case default metadata
	 *            will be used
	 * @return
	 * @throws InvalidDeploymentUnitException
	 */
	@Override
	public GenericApplicationContext deploy(String[] requiredSpringLocations, ResourceLoader resourceLoader,
			ComponentContributor componentContributor, DeploymentUnitMetadata deploymentUnitMetadata)
			throws InvalidDeploymentUnitException {
		return super.deploy(requiredSpringLocations, resourceLoader, componentContributor, deploymentUnitMetadata,
				SPRING_EJB_JAR_XML_LOCATION);
	}

}
