/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.jee.validation;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.HashSet;
import java.util.Set;

/**
 * 
 * @author Rod Johnson
 * 
 */
public class AnnotatedMethodSpecificationRule extends AbstractSpecificationRule {

	private final Method method;

	/**
	 * Object on which rule should be invoked
	 */
	private final Object instance;

	private Set<Platform> platforms = new HashSet<Platform>();

	public AnnotatedMethodSpecificationRule(Class annotationType, Object annotation, Method method, Object instance) {
		this.method = method;
		this.instance = instance;

		for (Platform p : Platform.values()) {
			if (p.getAnnotations().contains(annotationType)) {
				platforms.add(p);
			}
		}
		try {
			init(annotation);
		}
		catch (Exception ex) {
			throw new IllegalArgumentException("Invalid annotation", ex);
		}
	}

	private void init(Object annotation) throws IllegalArgumentException, SecurityException, IllegalAccessException,
			InvocationTargetException, NoSuchMethodException {
		int sh = (Integer) annotation.getClass().getMethod("subheading", (Class[]) null).invoke(annotation,
				(Object[]) null);
		int h = (Integer) annotation.getClass().getMethod("heading", (Class[]) null).invoke(annotation, (Object[]) null);
		int c = (Integer) annotation.getClass().getMethod("chapter", (Class[]) null).invoke(annotation, (Object[]) null);
		super.init(c, h, sh);
	}

	public Set<Platform> getPlatforms() {
		return platforms;
	}

	public void execute(Object o, InvalidDeploymentUnitException idum) {
		try {
			// log.info("About to validate with: " + method + " for component
			// with name='" + component.getComponentName() + "'");
			method.invoke(instance, new Object[] { o });
		}
		catch (IllegalArgumentException ex) {
			throw new UnsupportedOperationException();
		}
		catch (IllegalAccessException ex) {
			throw new UnsupportedOperationException();
		}
		catch (InvocationTargetException ex) {
			if (ex.getTargetException() instanceof SpecificationViolation) {
				// TODO take annotation on validation method and add it
				idum.addViolation((SpecificationViolation) ex.getTargetException());
			}
			else {
				throw new UnsupportedOperationException(ex);
			}
		}
	}

	public boolean appliesTo(Class<?> clazz) {
		return method.getParameterTypes()[0].isAssignableFrom(clazz);
	}

}
