/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.jee.validation;

import org.springframework.beans.BeansException;
import org.springframework.beans.factory.config.BeanPostProcessor;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.jee.inject.DeploymentUnitMetadata;

/**
 * ValidationService implementation designed for use in a Spring container.
 * Autodetects beans with Validation methods on them, configuring a
 * ReflectiveRuleBasedValidationService using them.
 * @author Rod Johnson
 *
 */
public class AutodetectValidationService implements ValidationService, BeanPostProcessor, ApplicationContextAware {
	
	private ApplicationContext applicationContext;
	
	private ReflectiveRuleBasedValidationService reflectiveRuleBasedValidationService = new ReflectiveRuleBasedValidationService();
	
	public void setApplicationContext(ApplicationContext applicationContext) throws BeansException {
		this.applicationContext = applicationContext;
	}

	public Object postProcessBeforeInitialization(Object bean, String beanName) throws BeansException {
		return bean;
	}
	
	public Object postProcessAfterInitialization(Object bean, String beanName) throws BeansException {
		if (applicationContext.isSingleton(beanName) &&
				bean.getClass().isAnnotationPresent(SpecificationRules.class)) {
			reflectiveRuleBasedValidationService.addPotentialValidator(bean);
		}
		return bean;
	}
	
	
	public int validate(DeploymentUnitMetadata dum) throws InvalidDeploymentUnitException {
		return reflectiveRuleBasedValidationService.validate(dum);
	}

}
