/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.jee.validation;

import java.util.Set;

/**
 * Synthetic interface used to wrap specification rule annotations,
 * also including the target method.
 * @author Rod Johnson
 *
 */
public interface SpecificationRule {
	
	/**
	 * @return the chapter from the specification.
	 * If it's 8.1.2, this would be 8.
	 */
	int getChapter();
	
	/**
	 * @return the heading from the chapter from the specification.
	 * If it's 8.1.2, this would be 1
	 */
	int getHeading();
	
	/**
	 * @return the subheading from the specification.
	 * E.g. if it's 8.1.2, this would be 2.
	 * Defaults to 0 if there is no subheading.
	 */
	int getSubheading();
	
	/**
	 * Return the method implementing the validation rule
	 * @return the method implementing the validation rule
	 */
	//Method getMethod();
	
	/**
	 * Return the set of JEE Platforms this rule
	 * relates to
	 * @return Platforms the rule represented by this location
	 * is valid for
	 */
	Set<Platform> getPlatforms();
	
	void execute(Object o, InvalidDeploymentUnitException dum);
	
	boolean appliesTo(Class<?> clazz);
	
}
