/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.jee.validation;

import org.springframework.jee.inject.Jsr250Metadata;

/**
 * Exception thrown when a specification violation is
 * found.
 * @author Rod Johnson
 * 
 */
public class SpecificationViolation extends Exception {

	private static final long serialVersionUID = 1L;
	
	// TODO Location object
	private String code;
	
	private final Jsr250Metadata componentMetadata; 

	public SpecificationViolation(String message, Jsr250Metadata componentMetadata) {
		super(message);
		this.componentMetadata = componentMetadata;
	}
	
	public void setCode(String code) {
		this.code = code;
	}

	/**
	 * @return the code associated with the given specification
	 * violation
	 */
	public String getCode() {
		return this.code;
	}
	
	/**
	 * @return the componentMetadata
	 */
	public Jsr250Metadata getComponentMetadata() {
		return this.componentMetadata;
	}
}
