/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.jee.validation.rules.ejb;

import org.springframework.jee.ejb.EjbInjectionMetadata;
import org.springframework.jee.inject.Injection;
import org.springframework.jee.validation.EJB_3_0;
import org.springframework.jee.validation.SpecificationRules;
import org.springframework.jee.validation.SpecificationViolation;

/**
 * Rules for validation @EJB injections.
 * @author Costin Leau
 * 
 */
@SpecificationRules
public class EjbRules {

	@EJB_3_0(chapter = 16, heading = 5)
	public void checkHasBusinessInterfaces(EjbInjectionMetadata eim) throws SpecificationViolation {
		for (Injection injection : eim.getEjbInjections()) {
			if (!injection.getType().isInterface()) {
				throw new SpecificationViolation(eim.getComponentClass()
						+ " can not use @EJB on " + injection.getType() + " as it is not an interface", eim);
			}
		}
	}
}
