/**
 * 
 */
package org.springframework.beans.factory.config;

import org.springframework.test.AbstractDependencyInjectionSpringContextTests;

/**
 * Identity test - make sure the post processor doesn't transform singletons
 * into prototypes.
 * 
 * @author Costin Leau
 * 
 */
public class IdentityTest extends AbstractDependencyInjectionSpringContextTests {

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.springframework.test.AbstractDependencyInjectionSpringContextTests#getConfigLocations()
	 */
	@Override
	protected String[] getConfigLocations() {
		return new String[] { "/org/springframework/beans/factory/config/simple-context.xml" };
	}

	public Object singleton;

	public Object prototype;

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.springframework.test.AbstractDependencyInjectionSpringContextTests#onSetUp()
	 */
	@Override
	protected void onSetUp() throws Exception {
		singleton = applicationContext.getBean("singleton");
		prototype = applicationContext.getBean("prototype");
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.springframework.test.AbstractDependencyInjectionSpringContextTests#onTearDown()
	 */
	@Override
	protected void onTearDown() throws Exception {
		super.onTearDown();
	}

	public void testSameBeanOnce() {
		Object myBean = applicationContext.getBean("singleton");
		assertSame(singleton, myBean);
	}

	public void testSameBeanTwice() {
		assertSame(singleton, applicationContext.getBean("singleton"));
		assertSame(singleton, applicationContext.getBean("singleton"));
		assertSame(singleton, applicationContext.getBean("singleton"));
		assertSame(singleton, applicationContext.getBean("singleton"));
		assertSame(singleton, applicationContext.getBean("singleton"));
	}

	public void testPrototypes() {
		assertNotSame(prototype, applicationContext.getBean("prototype"));
		assertNotSame(applicationContext.getBean("prototype"), applicationContext.getBean("prototype"));
	}

}
