/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.beans.factory.config;

import org.springframework.aop.support.AopUtils;
import org.springframework.test.AbstractDependencyInjectionSpringContextTests;

import sample.CountInterceptor;
import sample.EngineControl;

/**
 * Tests for automatic dependency injection of beans deployed into a Spring context
 * @author Rod Johnson
 *
 */
public class JeeBeanFactoryPostProcessorInterceptionTests extends AbstractDependencyInjectionSpringContextTests {
	
	private EngineControl engineControl;
	
	public void setEngineControl(EngineControl engineControl) {
		this.engineControl = engineControl;
	}
	
	
	@Override
	protected String[] getConfigLocations() {
		return new String[] { "org/springframework/beans/factory/config/jeeInterception.xml" };
	}
	
	public void testEngineControlIsProxied() {
		assertTrue("Engine control is a dynamic proxy", AopUtils.isJdkDynamicProxy(engineControl));
		CountInterceptor.count = 0;
		engineControl.start();
		assertEquals("Interceptor on class invoked", 1, CountInterceptor.count);
	}
}
