/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.beans.factory.config;

import org.springframework.test.AbstractDependencyInjectionSpringContextTests;

import sample.EngineControl;
import sample.LaundryMachine;

/**
 * Tests for automatic dependency injection of beans deployed into a Spring context
 * @author Rod Johnson
 *
 */
public class JeeBeanFactoryPostProcessorResourceInjectionTests extends AbstractDependencyInjectionSpringContextTests {
	
	private LaundryMachine laundryMachine;
	
	private EngineControl engineControl;
	
	public void setEngineControl(EngineControl engineControl) {
		this.engineControl = engineControl;
	}
	
	public void setLaundryMachine(LaundryMachine laundryMachine) {
		this.laundryMachine = laundryMachine;
	}
	
	@Override
	protected String[] getConfigLocations() {
		return new String[] { "org/springframework/beans/factory/config/resourceInjection.xml" };
	}
	
	public void testEngineControlWasInjectedIntoLaundryMachine() {
		assertNotNull("EngineControl was injected into LaundryMachine",
				laundryMachine.getEngineControl());
		
		// TODO check this, depends on prototype behaviour
//		assertSame("EngineControl was injected into LaundryMachine",
//				engineControl, laundryMachine.getEngineControl());
	}

}
