/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.jee.config;

import junit.framework.TestCase;

import org.springframework.beans.factory.support.RootBeanDefinition;
import org.springframework.context.support.GenericApplicationContext;
import org.springframework.transaction.PlatformTransactionManager;
import org.springframework.transaction.TransactionDefinition;
import org.springframework.transaction.TransactionException;
import org.springframework.transaction.TransactionStatus;

public class ServiceEnvironmentTests extends TestCase {

	private static class DummyTransactionManager implements PlatformTransactionManager {

		/*
		 * (non-Javadoc)
		 * 
		 * @see org.springframework.transaction.PlatformTransactionManager#commit(org.springframework.transaction.TransactionStatus)
		 */
		public void commit(TransactionStatus status) throws TransactionException {
		}

		/*
		 * (non-Javadoc)
		 * 
		 * @see org.springframework.transaction.PlatformTransactionManager#getTransaction(org.springframework.transaction.TransactionDefinition)
		 */
		public TransactionStatus getTransaction(TransactionDefinition definition) throws TransactionException {
			return null;
		}

		/*
		 * (non-Javadoc)
		 * 
		 * @see org.springframework.transaction.PlatformTransactionManager#rollback(org.springframework.transaction.TransactionStatus)
		 */
		public void rollback(TransactionStatus status) throws TransactionException {
		}

	}

	public void testAutodetectBeanFactoryServiceEnvironment() throws Exception {
		GenericApplicationContext context = new GenericApplicationContext();
		context.registerBeanDefinition("tm", new RootBeanDefinition(DummyTransactionManager.class));

		ServiceEnvironment env = new AutodetectBeanFactoryServiceEnvironment(context);
		assertSame(context.getBean("tm"), env.getTransactionManager());

		context.registerBeanDefinition("anotherTm", new RootBeanDefinition(DummyTransactionManager.class));
		env = new AutodetectBeanFactoryServiceEnvironment(context);
		assertSame(context.getBean("tm"), env.getTransactionManager());

	}
	
}
