/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.jee.ejb;

import java.util.ArrayList;

import org.springframework.jee.inject.AnnotationComponentContributor;
import org.springframework.jee.inject.DeploymentUnitMetadata;
import org.springframework.jee.inject.Jsr250Metadata;
import org.springframework.jee.inject.MetadataProcessor;

/**
 * Component contributor for EJB3 environments.
 * 
 * @author Costin Leau
 * 
 */
public class EjbAnnotationComponentContributor extends AnnotationComponentContributor {

	public EjbAnnotationComponentContributor(Class... classes) {
		super(classes);
		metadataProcessors = new ArrayList<MetadataProcessor>(3);
		metadataProcessors.addAll(DEFAULT_PROCESSORS);
		metadataProcessors.add(new EjbReferenceProcessor());
	}

	@Override
	public Jsr250Metadata newJsr250Metadata(String componentName, Class<?> componentClass, DeploymentUnitMetadata dum) {
		return new EjbInjectionMetadata(dum, componentName, componentClass);
	}

}
