/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.jee.ejb;

import org.springframework.test.AbstractDependencyInjectionSpringContextTests;

import sample.CountInterceptor;
import sample.EngineControl;
import sample.LaundryMachine;

public class EjbApplicationContextTests extends AbstractDependencyInjectionSpringContextTests {

	@Override
	protected String[] getConfigLocations() {
		return new String[] { "/org/springframework/jee/ejb/ejb-context.xml" };
	}

	public void testEjbInjection() throws Exception {
		Object bean = applicationContext.getBean("bean");
		assertNotNull(bean);
		assertTrue(bean instanceof EjbLaundryMachine);
		EjbLaundryMachine machine = (EjbLaundryMachine) bean;
		assertNotNull("@ejb injection not applied ", machine.getAnotherEngine());
		assertSame("injection not applied correctly", applicationContext.getBean("engineControl"),
				machine.getAnotherEngine());
		assertTrue(bean instanceof LaundryMachine);
		assertNotNull("@ejb injection not applied ", ((LaundryMachine) bean).getEngineControl());
	}

	public void testDependencyJSR250() throws Exception {
		
		assertEquals(0, CountInterceptor.count);
		LaundryMachine machine = (LaundryMachine) applicationContext.getBean("bean");
		assertNotNull(machine.getEngineControl());
		machine.getEngineControl().start();
		assertEquals(1, CountInterceptor.count);
	}

	public void testEjbOnEjbDependency() throws Exception {
		LaundryMachine machine = (LaundryMachine) applicationContext.getBean("bean");
		EjbLaundryMachineFetcher ctrl = (EjbLaundryMachineFetcher) machine.getEngineControl();
		assertNotNull(ctrl.getEjbLaundryMachine());
		assertSame(applicationContext.getBean("ejbLaundryMachine"), ctrl.getEjbLaundryMachine());
		
	}

	@Override
	protected void onSetUp() throws Exception {
		CountInterceptor.count = 0;
	}
	
	
}
