/**
 * 
 */
package org.springframework.jee.intercept;

import javax.annotation.PostConstruct;
import javax.annotation.PreDestroy;
import javax.annotation.Resource;
import javax.interceptor.AroundInvoke;
import javax.interceptor.InvocationContext;

import sample.DefaultInterceptorWithDependencies;
import sample.EngineControl;

/**
 * Yet another default interceptor.
 * 
 * @author Costin Leau
 * 
 */
public class DefaultChildInterceptorWithDependencies extends DefaultInterceptorWithDependencies {

	public static int childCount;

	public static boolean anotherInstance;

	public static boolean childPostConstruct = false;

	public static boolean childPreDestroy = false;

	public static boolean shortCircuitPostConstruct = false;

	@Resource
	private EngineControl childEngineControl;

	@AroundInvoke
	public Object countChildCall(InvocationContext ic) throws Exception {
		if (childEngineControl == null) {
			throw new IllegalStateException("Interceptor with dependencies was not injected");
		}
		String key = DefaultNephewInterceptorWithDependencies.class.getName();
		Object obj = ic.getContextData().get(key);

		if (obj == null)
			ic.getContextData().put(key, this);
		else
			anotherInstance = !(obj == this);

		order.add(this.getClass());

		++childCount;
		return ic.proceed();
	}

	@PostConstruct
	private void childPostConstruct(InvocationContext ic) {
		childPostConstruct = true;
		if (!shortCircuitPostConstruct)
			try {
				ic.proceed();
			}
			catch (Exception e) {
				throw new RuntimeException(e);
			}
	}

	@PreDestroy
	protected void childPreDestroy(InvocationContext ic) {
		childPreDestroy = true;
		try {
			ic.proceed();
		}
		catch (Exception e) {
			throw new RuntimeException(e);
		}
	}

}
