package org.springframework.jee.intercept;

import java.lang.reflect.Method;
import java.util.Iterator;
import java.util.Map;

import junit.framework.TestCase;

import org.easymock.EasyMock;
import org.springframework.context.ApplicationContext;
import org.springframework.jee.config.ServiceEnvironment;
import org.springframework.jee.config.SimpleServiceEnvironment;
import org.springframework.jee.inject.AnnotationComponentContributor;
import org.springframework.jee.inject.ChainedProcessorsComponentContributor;
import org.springframework.jee.inject.DeploymentUnitMetadata;
import org.springframework.jee.inject.InterceptedBean;
import org.springframework.jee.intercept.InterceptionMetadata.InterceptorExclusion;
import org.springframework.jee.server.Bootstrap;
import org.springframework.jee.server.TrackingAnnotationComponentContributor;
import org.springframework.transaction.PlatformTransactionManager;

import sample.CountInterceptor;
import sample.SpringInjected;
import sample.intercept.StartInterceptor;

/**
 * 
 * @author Costin Leau
 * 
 */
public class ExcludeInterceptionTests extends TestCase {

	private TrackingAnnotationComponentContributor acc = new TrackingAnnotationComponentContributor();

	private SpringInjected bean;

	protected void setUp() throws Exception {
		Bootstrap bootstrap = new Bootstrap();
		AnnotationComponentContributor ms = new AnnotationComponentContributor(
				InterceptedBean.class);
		ms.setMetadataProcessors(ChainedProcessorsComponentContributor.INTERCEPTION_PROCESSORS);
		ApplicationContext jarAc = bootstrap.deploy(ms);

		bean = (SpringInjected) jarAc.getBean(InterceptedBean.class
				.getSimpleName());
	}

	protected void tearDown() throws Exception {
		super.tearDown();
		bean = null;
	}
	
	protected DeploymentUnitMetadata createDummyDeploymentUnitMetadata() {
		//GenericApplicationContext deploymentContext = new GenericApplicationContext();
		DeploymentUnitMetadata unit = new DeploymentUnitMetadata();
		ServiceEnvironment dummyEnv = new SimpleServiceEnvironment(EasyMock.createNiceMock(PlatformTransactionManager.class));
		unit.setEnvironment(dummyEnv);
		return unit;
	}

	public void testExcludeInterceptor() throws Exception {

		// test exclude annotation
		CountInterceptor.count = StartInterceptor.count = 0;

		bean.getStrings();
		assertEquals("method interceptors applied", 1, StartInterceptor.count);
		// count interceptor should have been excluded
		assertEquals("count interceptor should be excluded", 0,
				CountInterceptor.count);
	}

	public void testExcludeInfo() throws Exception {
		InterceptionMetadata meta = acc.findComponentMetadata("foobar", InterceptedBean.class, createDummyDeploymentUnitMetadata());
		Map<Method, InterceptorExclusion> exclusions = meta.getExclusion();
		assertEquals("exclude annotations not read correctly", 2, exclusions.size());
		Iterator<InterceptorExclusion> excludes = exclusions.values().iterator();
		assertTrue("exclude class not found", excludes.next().isExcludeClassInterceptors());
		assertTrue("exclude class not found", excludes.next().isExcludeDefaultInterceptors());
	}
	
	public void testMarkedClassInterceptor() throws Exception {
		InterceptionMetadata meta = acc.findComponentMetadata("foobar", InterceptedBean.class, createDummyDeploymentUnitMetadata());
		InterceptorMetadata interceptData = meta.getInterceptorMetadata().get(0);
		assertTrue("does not mark correctly class interceptors" , interceptData.isClassInterceptor());
		assertFalse("does not mark correctly default interceptors" , interceptData.isDefaultInterceptor());
	}
}
