/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.jee.server;

import java.util.LinkedList;
import java.util.List;

import org.springframework.jee.inject.AnnotationComponentContributor;
import org.springframework.jee.inject.DeploymentUnitMetadata;
import org.springframework.jee.intercept.InterceptionMetadata;

/**
 * Test subclass of AnnotationComponentContributor that keeps a reference to deployed components,
 * in order.
 * 
 * @author Rod Johnson
 *
 */
public class TrackingAnnotationComponentContributor extends AnnotationComponentContributor {
	
	private List<InterceptionMetadata> components = new LinkedList<InterceptionMetadata>();
	
	public TrackingAnnotationComponentContributor(Class... classes) {
		super(classes);
	}
	
	@Override
	public InterceptionMetadata findComponentMetadata(String componentName, Class<?> componentClass, DeploymentUnitMetadata dum) {
		InterceptionMetadata im = (InterceptionMetadata) super.findComponentMetadata(componentName, componentClass, dum);
		components.add(im);
		return im;
	}
	
	/**
	 * @return a list of deployed components, in the order in which they were deployed
	 */
	public List<InterceptionMetadata> getDeployedComponents() {
		return components;
	}
}