/**
 * 
 */
package org.springframework.jee.transaction;

import javax.ejb.CreateException;
import javax.ejb.Stateless;
import javax.ejb.TransactionAttribute;
import javax.ejb.TransactionAttributeType;

import org.springframework.core.NestedRuntimeException;

/**
 * Business interface implementation that uses an internal singleton for executing the methods. This allows tests to replace the underlying implementation
 * add throw custom exceptions through ad-hoc inner classes.
 * 
 * @author Costin Leau
 * 
 */
@Stateless
public class DelegateStatelessBean implements BusinessInterface {

	private BusinessInterface delegate; 
	
	@TransactionAttribute(TransactionAttributeType.MANDATORY)
	public void methodWithApplicationException() throws NoSuchMethodException {
		delegate.methodWithApplicationException();
	}

	@TransactionAttribute(TransactionAttributeType.NEVER)
	public void methodWithError() throws Error {
		delegate.methodWithError();
	}

	@TransactionAttribute(TransactionAttributeType.REQUIRES_NEW)
	public void methodWithException() throws Exception {
		delegate.methodWithException();
	}

	@TransactionAttribute(TransactionAttributeType.SUPPORTS)
	public void methodWithMultipleExceptions() throws NoSuchFieldException, UnsupportedOperationException,
			IllegalArgumentException, InterruptedException, CreateException {
		delegate.methodWithMultipleExceptions();
	}

	public void simpleMethod() {
		delegate.simpleMethod();
	}

	public void nonBusinessInterfaceMethod() {
	}

	/**
	 * @return Returns the delegate.
	 */
	public BusinessInterface getDelegate() {
		return delegate;
	}

	/**
	 * @param delegate The delegate to set.
	 */
	public void setDelegate(BusinessInterface delegate) {
		this.delegate = delegate;
	}

	
	
}
