/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.jee.validation;

import java.awt.Point;

import junit.framework.TestCase;

import org.springframework.jee.inject.DeploymentUnitMetadata;
import org.springframework.jee.intercept.InterceptionMetadata;
import org.springframework.jee.server.TrackingAnnotationComponentContributor;
import org.springframework.jee.validation.rules.InterceptionRules;

/**
 * @author Rod Johnson
 *
 */
public class ReflectiveRuleBasedValidationServiceTests extends TestCase {
	
	private ReflectiveRuleBasedValidationService rrbvs = new ReflectiveRuleBasedValidationService();
	
	private TrackingAnnotationComponentContributor tacc = new TrackingAnnotationComponentContributor();
	
	protected DeploymentUnitMetadata createDeploymentUnitMetadata() {
		//GenericApplicationContext deploymentContext = new GenericApplicationContext();
		return new DeploymentUnitMetadata();
	}
	
	public void testNoRulesPass() throws InvalidDeploymentUnitException {
		DeploymentUnitMetadata deploymentUnitMetadata =createDeploymentUnitMetadata();
		InterceptionMetadata im = tacc.findComponentMetadata("foo", Point.class, deploymentUnitMetadata);
		int componentsValidated = rrbvs.validate(deploymentUnitMetadata);
		assertEquals(1, componentsValidated);
	}
	
	public void testBogusInterceptionClassVetoed() {
		rrbvs.addPotentialValidator(new InterceptionRules());
		
		// Bogus class
		DeploymentUnitMetadata deploymentUnitMetadata = createDeploymentUnitMetadata();
		InterceptionMetadata im = tacc.findComponentMetadata("foo", Point.class, deploymentUnitMetadata);
		try {
			rrbvs.validate(deploymentUnitMetadata);
			fail("Should not accept deployment of component without business interfaces");
		}
		catch (InvalidDeploymentUnitException ex) {
			// Ok
		}
		
	}

}
