/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.jee.validation.rules.ejb;

import java.awt.Point;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.ejb.EJB;

import junit.framework.TestCase;

import org.springframework.jee.ejb.EjbInjectionMetadata;
import org.springframework.jee.ejb.EjbLaundryMachine;
import org.springframework.jee.ejb.EjbReferenceInfo;
import org.springframework.jee.ejb.EjbReferenceProcessor;
import org.springframework.jee.inject.AnnotationComponentContributor;
import org.springframework.jee.inject.ChainedProcessorsComponentContributor;
import org.springframework.jee.inject.DeploymentUnitMetadata;
import org.springframework.jee.inject.Jsr250Metadata;
import org.springframework.jee.inject.MetadataProcessor;
import org.springframework.jee.validation.InvalidDeploymentUnitException;
import org.springframework.jee.validation.ReflectiveRuleBasedValidationService;

import sample.EngineControl;

public class EjbRulesTests extends TestCase {
	private ReflectiveRuleBasedValidationService rrbvs;

	private AnnotationComponentContributor acc;

	private class Foo {
		@EJB
		Point point;

	}

	private class Bar {
		@EJB(beanInterface = Serializable.class)
		Point point;
	}

	protected DeploymentUnitMetadata createDeploymentUnitMetadata() {
		return new DeploymentUnitMetadata();
	}

	public void testBogusEJBInjectionClassVetoed() {
		// Bogus class
		DeploymentUnitMetadata deploymentUnitMetadata = createDeploymentUnitMetadata();
		EjbInjectionMetadata metadata = (EjbInjectionMetadata) acc.findComponentMetadata("foo", Foo.class,
				deploymentUnitMetadata);
		try {
			rrbvs.validate(deploymentUnitMetadata);
			fail("Should not accept deployment of component that use @EJB injection for non-business-interfaces");
		}
		catch (InvalidDeploymentUnitException ex) {
			// Ok
		}

	}

	public void testCorrectEJBClassVetoed() throws Exception {
		DeploymentUnitMetadata deploymentUnitMetadata = createDeploymentUnitMetadata();
		EjbInjectionMetadata metadata = (EjbInjectionMetadata) acc.findComponentMetadata("bar", Bar.class,
				deploymentUnitMetadata);
		rrbvs.validate(deploymentUnitMetadata);
	}

	@Override
	protected void setUp() throws Exception {
		acc = new AnnotationComponentContributor() {

			@Override
			public Jsr250Metadata newJsr250Metadata(String componentName, Class<?> componentClass,
					DeploymentUnitMetadata dum) {
				return new EjbInjectionMetadata(dum, componentName, componentClass);
			}
		};
		List<MetadataProcessor> processors = new ArrayList<MetadataProcessor>();
		processors.addAll(ChainedProcessorsComponentContributor.DEFAULT_PROCESSORS);
		processors.add(new EjbReferenceProcessor());
		acc.setMetadataProcessors(processors);

		rrbvs = new ReflectiveRuleBasedValidationService();
		rrbvs.addPotentialValidator(new EjbRules());
	}

	@Override
	protected void tearDown() throws Exception {
		acc = null;
		rrbvs = null;
	}

}
