/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package sample;

import java.util.ArrayList;
import java.util.List;

import javax.annotation.Resource;
import javax.interceptor.AroundInvoke;
import javax.interceptor.InvocationContext;

/**
 * Interceptor that itself requires DI
 * @author Michael Chen
 *
 */
public class DefaultBaseInterceptorWithDependencies {
    
    public static int countBase;
    
	public static List<Class> order = new ArrayList<Class>();

	public static final String LIST_KEY = "ORDER KEY";
	
    @Resource
    private EngineControl engineControl;
    
    @AroundInvoke
    public Object countCallInheritance(InvocationContext ic) throws Exception {
    	if (engineControl == null) {
    		throw new IllegalStateException("Interceptor with dependencies was not injected");
    	}
        ++countBase;

        order.add(this.getClass());
        
        return ic.proceed();
    }


	protected void keepOrderTrack(InvocationContext ic) {

		// keep track of order call
		getOrderList(ic).add(this.getClass());
	}

	protected List<Class> getOrderList(InvocationContext ic) {
		Object list = ic.getContextData().get(LIST_KEY);
		if (list == null) {
			list = new ArrayList<Class>();
			ic.getContextData().put(LIST_KEY, list);
		}
		return (List<Class>) list;
	}
}
