/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package sample;

import javax.annotation.PreDestroy;
import javax.annotation.Resource;
import javax.ejb.Stateless;

@Stateless
public class LaundryMachineBean implements LaundryMachine {
	
    public String manufacturer = null;
    public String model = null;
    
    public boolean preDestroyCalled;

    private EngineControl engineControl = null;


    public String getManufacturer() {
        return manufacturer;
    }

    public String getModel() {
        return model;
    }

    public EngineControl getEngineControl() {
        return engineControl;
    }

    @Resource(name="EngineControlBean")
    public void setEngineControl(EngineControl engineControl) {
    	if (this.engineControl != null) {
    		throw new IllegalStateException("Multiple injection via @Resource");
    	}
        this.engineControl = engineControl;
    }


    public void startEngine() {
        this.engineControl.start();
    }

    public void stopEngine() {
        this.engineControl.stop();
    }
    
    @PreDestroy
    protected void nameDoesntMatter() {
    	this.preDestroyCalled = true;
    }
    
    public boolean preDestroyCalled() {
    	return preDestroyCalled;
    }
    
}
