/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package sample;

import javax.annotation.PostConstruct;
import javax.interceptor.AroundInvoke;
import javax.interceptor.InvocationContext;

/**
 * 
 * @author Rod Johnson
 *
 */
public class PostConstructInterceptor {
	
	private boolean postConstructCalled;
	
	private boolean postConstructListenerInvoked;

	@PostConstruct
	public void anyName() {
		if (postConstructCalled) {
			throw new IllegalStateException("PostConstruct method must only be invoked once");
		}
		this.postConstructCalled = true;
	}
	
	@PostConstruct
	public void anyName(InvocationContext ic) throws Exception {
		if (postConstructListenerInvoked) {
			throw new IllegalStateException("PostConstruct listener method must only be invoked once");
		}
		this.postConstructListenerInvoked = true;
		ic.proceed();
	}
	
	@AroundInvoke
	public Object handlePostConstruct(InvocationContext ic) throws Exception {
		// The absence of pointcuts is truly horrible..
		if ("postConstructCalled".equals(ic.getMethod().getName())) {
			return postConstructCalled && postConstructListenerInvoked;
		}
		else {
			return ic.proceed();
		}
	}

}
