/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package sample;

import java.rmi.RemoteException;
import java.util.List;

import javax.ejb.EJBException;
import javax.ejb.SessionSynchronization;
import javax.ejb.Stateful;
import javax.ejb.TransactionAttribute;

import junit.framework.Assert;

@Stateful
public class SessionSynchronizationMemoryManagerBean extends MemoryManagerBean implements SessionSynchronization {
	
	private boolean inTransaction;
	
	private int beforeCompletionCalls;

	public boolean isInTransaction() {
		return inTransaction;
	}
	
	public int getBeforeCompletionCalls() {
		return beforeCompletionCalls;
	}
	
	public void afterBegin() throws EJBException, RemoteException {
		inTransaction = true;
	}

	public void beforeCompletion() throws EJBException, RemoteException {
		++beforeCompletionCalls;
	}

	public void afterCompletion(boolean fate) throws EJBException, RemoteException {
		inTransaction = false;
	}
	
	@Override
	@TransactionAttribute
	public List getAllContacts() {
		Assert.assertTrue("Must have received SessionSynchronization callback", inTransaction);
		return super.getAllContacts();
	}

}
