/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package sample;

import javax.annotation.PreDestroy;
import javax.ejb.PostActivate;
import javax.ejb.PrePassivate;
import javax.ejb.Stateful;
import javax.interceptor.Interceptors;

/**
 * 
 * @author Rod Johnson
 *
 */
@Stateful
@Interceptors({CountInterceptor.class, PreDestroyInterceptor.class})
public class StatefulMemoryManager extends MemoryManagerBean {
	
	private int passivations;
	private int activations;
	
	public static int preDestroys;
	
	@PostActivate
	public void activated() {
		++activations;
	}
	
	@PrePassivate
	public void passivated() {
		++passivations;
	}
	
	@Override
	public int getPassivationCount() {
		return passivations;
	}
	
	@Override
	public int getActivationCount() {
		return activations;
	}
	
	@PreDestroy
	public void nameShouldNotMatter() {
		++preDestroys;
	}

}
