/*
 * Copyright 2002-2006 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.jee.validation;

import java.util.LinkedList;
import java.util.List;

/**
 * Enumeration for JEE Platform revisions.
 * Identifies different specification rule annotations
 * that should be applied for objects in this platform.
 * @author Rod Johnson
 *
 */
public enum Platform {
	
	JEE_5_0(CommonAnnotations_1_0.class, EJB_3_0.class),
	
	// Proof of concept, not currently used
	JEE_6_0(CommonAnnotations_1_0.class, EJB_3_1.class);
	
	private List<Class> annotations;
	
	private Platform(Class... annotations) {
		this.annotations = new LinkedList<Class>();
		for (Class ann : annotations) {
			this.annotations.add(ann);
		}
	}
	
	public List<Class> getAnnotations() {
		return this.annotations;
	}
	

}
